@@ -28,7 +28,6 @@
 #include "nautilus-global-preferences.h"
 #include "nautilus-lib-self-check-functions.h"
 #include "nautilus-metadata.h"
-#include "nautilus-metafile.h"
 #include "nautilus-file.h"
 #include "nautilus-search-directory.h"
 #include "nautilus-signaller.h"
@@ -39,6 +38,7 @@
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 #include <gio/gio.h>
+#include <dbus/dbus-glib.h>
 #include <unistd.h>
 #include <stdlib.h>
 
@@ -111,6 +111,27 @@ nautilus_get_user_directory (void)
 	return user_directory;
 }
 
+/**
+ * nautilus_get_accel_map_file:
+ * 
+ * Get the path for the filename containing nautilus accelerator map.
+ * The filename need not exist.
+ *
+ * Return value: the filename path, or NULL if the home directory could not be found
+ **/
+char *
+nautilus_get_accel_map_file (void)
+{
+	const gchar *home;
+
+	home = g_get_home_dir();
+	if (home != NULL) {
+		return g_build_filename (home, ".gnome2/accels/nautilus", NULL);
+	}
+
+	return NULL;
+}
+
 typedef struct {
 	char *type;
 	char *path;
@@ -255,8 +276,11 @@ xdg_dir_changed (NautilusFile *file,
 				      G_SPAWN_STDERR_TO_DEV_NULL,
 				      NULL, NULL,
 				      NULL, NULL, NULL, NULL);
+			g_reload_user_special_dirs_cache ();
 			schedule_user_dirs_changed ();
 			desktop_dir_changed ();
+			/* Icon might have changed */
+			nautilus_file_invalidate_attributes (file, NAUTILUS_FILE_ATTRIBUTE_INFO);
 		}
 	}
 	g_object_unref (location);
@@ -346,6 +370,7 @@ update_xdg_dir_cache (void)
 	int i;
 
 	free_xdg_dir_cache ();
+	g_reload_user_special_dirs_cache ();
 	schedule_user_dirs_changed ();
 	desktop_dir_changed ();
 
@@ -812,7 +837,7 @@ nautilus_unique_temporary_file_name (void)
 
 	file_name = g_strdup_printf ("%sXXXXXX", prefix);
 
-	fd = mkstemp (file_name); 
+	fd = g_mkstemp (file_name); 
 	if (fd == -1) {
 		g_free (file_name);
 		file_name = NULL;
@@ -975,6 +1000,166 @@ nautilus_is_file_roller_installed (void)
 	return installed > 0 ? TRUE : FALSE;
 }
 
+#define GSM_NAME  "org.gnome.SessionManager"
+#define GSM_PATH "/org/gnome/SessionManager"
+
+/* The following values come from
+ * http://www.gnome.org/~mccann/gnome-session/docs/gnome-session.html#org.gnome.SessionManager.Inhibit 
+ */
+#define INHIBIT_LOGOUT 1
+#define INHIBIT_SUSPEND 4
+
+static DBusGProxy *_gsm_proxy = NULL;
+
+static DBusGProxy *
+get_power_manager_proxy (void)
+{
+	if (!_gsm_proxy)
+	{
+		DBusGConnection *bus;
+		GError *error;
+
+		error = NULL;
+		bus = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
+		if (!bus)
+		{
+			g_warning ("Could not connect to session bus: %s",
+				   error->message);
+			g_error_free (error);
+			return NULL;
+		}
+
+		_gsm_proxy = dbus_g_proxy_new_for_name (bus,
+						        GSM_NAME,
+						        GSM_PATH,
+						        GSM_NAME);
+		dbus_g_connection_unref (bus);
+
+		if (!_gsm_proxy)
+		{
+			g_warning ("Creating DBus proxy failed.");
+			return NULL;
+		}
+	}
+
+	return _gsm_proxy;
+}
+
+/**
+ * nautilus_inhibit_power_manager:
+ * @message: a human readable message for the reason why power management
+ *       is being suspended.
+ *
+ * Inhibits the power manager from logging out or suspending the machine
+ * (e.g. whenever Nautilus is doing file operations).
+ *
+ * Returns: an integer cookie, which must be passed to
+ *    nautilus_uninhibit_power_manager() to resume
+ *    normal power management.
+ */
+int
+nautilus_inhibit_power_manager (const char *message)
+{
+	DBusGProxy *proxy;
+	GError *error;
+	int cookie;
+
+	proxy = get_power_manager_proxy ();
+
+	g_return_val_if_fail (proxy != NULL, -1);
+
+	error = NULL;
+	cookie = -1;
+	if (!dbus_g_proxy_call (proxy, "Inhibit", &error,
+				G_TYPE_STRING, "Nautilus",
+				G_TYPE_UINT, 0,
+				G_TYPE_STRING, message,
+				G_TYPE_UINT, INHIBIT_LOGOUT | INHIBIT_SUSPEND,
+				G_TYPE_INVALID,
+				G_TYPE_UINT, &cookie,
+				G_TYPE_INVALID))
+	{
+		g_warning ("Could not inhibit power management: %s", error->message);
+		g_error_free (error);
+		return -1;
+	}
+
+	return cookie;
+}
+
+/**
+ * nautilus_uninhibit_power_manager:
+ * @cookie: the cookie value returned by nautilus_inhibit_power_manager()
+ *
+ * Uninhibits power management. This function must be called after the task
+ * which inhibited power management has finished, or the system will not
+ * return to normal power management.
+ */
+void
+nautilus_uninhibit_power_manager (gint cookie)
+{
+	DBusGProxy *proxy;
+	GError *error;
+	g_return_if_fail (cookie > 0);
+
+	proxy = get_power_manager_proxy ();
+
+	g_return_if_fail (proxy != NULL);
+
+	error = NULL;
+
+	if (!dbus_g_proxy_call (proxy, "Uninhibit", &error,
+                                G_TYPE_UINT, cookie,
+                                G_TYPE_INVALID,
+                                G_TYPE_INVALID))
+	{
+		g_warning ("Could not uninhibit power management: %s", error->message);
+		g_error_free (error);
+	}
+}
+
+/* Returns TRUE if the file is in XDG_DATA_DIRS or
+   in "~/.gnome2/". This is used for deciding
+   if a desktop file is "trusted" based on the path */
+gboolean
+nautilus_is_in_system_dir (GFile *file)
+{
+	const char * const * data_dirs; 
+	char *path, *gnome2;
+	int i;
+	gboolean res;
+	
+	if (!g_file_is_native (file)) {
+		return FALSE;
+	}
+
+	path = g_file_get_path (file);
+	
+	res = FALSE;
+
+	data_dirs = g_get_system_data_dirs ();
+	for (i = 0; path != NULL && data_dirs[i] != NULL; i++) {
+		if (g_str_has_prefix (path, data_dirs[i])) {
+			res = TRUE;
+			break;
+		}
+		
+	}
+
+	if (!res) {
+		/* Panel desktop files are here, trust them */
+		gnome2 = g_build_filename (g_get_home_dir (), ".gnome2", NULL);
+		if (g_str_has_prefix (path, gnome2)) {
+			res = TRUE;
+		}
+		g_free (gnome2);
+	}
+	g_free (path);
+	
+	return res;
+}
+
+
 #if !defined (NAUTILUS_OMIT_SELF_CHECK)
 
 void
