@@ -30,7 +30,7 @@
 #ifndef NAUTILUS_TREE_VIEW_DRAG_DEST_H
 #define NAUTILUS_TREE_VIEW_DRAG_DEST_H
 
-#include <gtk/gtktreeview.h>
+#include <gtk/gtk.h>
 
 #include "nautilus-file.h"
 
@@ -64,7 +64,7 @@ struct _NautilusTreeViewDragDestClass {
 				 GdkDragAction action,
 				 int x,
 				 int y);
-	void (* handle_url)     (NautilusTreeViewDragDest *dest,
+	void (* handle_netscape_url) (NautilusTreeViewDragDest *dest,
 				 const char *url,
 				 const char *target_uri,
 				 GdkDragAction action,
