@@ -51,6 +51,7 @@
 #define FM_ACTION_PASTE_FILES_INTO "Paste Files Into"
 #define FM_ACTION_LOCATION_PASTE_FILES_INTO "LocationPasteFilesInto"
 #define FM_ACTION_NEW_LAUNCHER "New Launcher"
+#define FM_ACTION_NEW_LAUNCHER_DESKTOP "New Launcher Desktop"
 #define FM_ACTION_RENAME "Rename"
 #define FM_ACTION_DUPLICATE "Duplicate"
 #define FM_ACTION_CREATE_LINK "Create Link"
@@ -69,14 +70,23 @@
 #define FM_ACTION_UNMOUNT_VOLUME "Unmount Volume"
 #define FM_ACTION_EJECT_VOLUME "Eject Volume"
 #define FM_ACTION_FORMAT_VOLUME "Format Volume"
+#define FM_ACTION_START_VOLUME "Start Volume"
+#define FM_ACTION_STOP_VOLUME "Stop Volume"
+#define FM_ACTION_POLL "Poll"
 #define FM_ACTION_SELF_MOUNT_VOLUME "Self Mount Volume"
 #define FM_ACTION_SELF_UNMOUNT_VOLUME "Self Unmount Volume"
 #define FM_ACTION_SELF_EJECT_VOLUME "Self Eject Volume"
 #define FM_ACTION_SELF_FORMAT_VOLUME "Self Format Volume"
+#define FM_ACTION_SELF_START_VOLUME "Self Start Volume"
+#define FM_ACTION_SELF_STOP_VOLUME "Self Stop Volume"
+#define FM_ACTION_SELF_POLL "Self Poll"
 #define FM_ACTION_LOCATION_MOUNT_VOLUME "Location Mount Volume"
 #define FM_ACTION_LOCATION_UNMOUNT_VOLUME "Location Unmount Volume"
 #define FM_ACTION_LOCATION_EJECT_VOLUME "Location Eject Volume"
 #define FM_ACTION_LOCATION_FORMAT_VOLUME "Location Format Volume"
+#define FM_ACTION_LOCATION_START_VOLUME "Location Start Volume"
+#define FM_ACTION_LOCATION_STOP_VOLUME "Location Stop Volume"
+#define FM_ACTION_LOCATION_POLL "Location Poll"
 #define FM_ACTION_SCRIPTS "Scripts"
 #define FM_ACTION_NEW_DOCUMENTS "New Documents"
 #define FM_ACTION_NEW_EMPTY_FILE "New Empty File"
