@@ -28,27 +28,31 @@
 #ifndef FM_DIRECTORY_VIEW_H
 #define FM_DIRECTORY_VIEW_H
 
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 #include <eel/eel-background.h>
 #include <libnautilus-private/nautilus-directory.h>
 #include <libnautilus-private/nautilus-file.h>
 #include <libnautilus-private/nautilus-icon-container.h>
 #include <libnautilus-private/nautilus-link.h>
-#include <eel/eel-string-list.h>
 #include <libnautilus-private/nautilus-view.h>
 #include <libnautilus-private/nautilus-window-info.h>
+#include <libnautilus-private/nautilus-window-slot-info.h>
+#include <gio/gio.h>
 
 typedef struct FMDirectoryView FMDirectoryView;
 typedef struct FMDirectoryViewClass FMDirectoryViewClass;
 
-#define FM_TYPE_DIRECTORY_VIEW			(fm_directory_view_get_type ())
-#define FM_DIRECTORY_VIEW(obj)			(GTK_CHECK_CAST ((obj), FM_TYPE_DIRECTORY_VIEW, FMDirectoryView))
-#define FM_DIRECTORY_VIEW_CLASS(klass)		(GTK_CHECK_CLASS_CAST ((klass), FM_TYPE_DIRECTORY_VIEW, FMDirectoryViewClass))
-#define FM_IS_DIRECTORY_VIEW(obj)		(GTK_CHECK_TYPE ((obj), FM_TYPE_DIRECTORY_VIEW))
-#define FM_IS_DIRECTORY_VIEW_CLASS(klass)	(GTK_CHECK_CLASS_TYPE ((klass), FM_TYPE_DIRECTORY_VIEW))
+#define FM_TYPE_DIRECTORY_VIEW fm_directory_view_get_type()
+#define FM_DIRECTORY_VIEW(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST ((obj), FM_TYPE_DIRECTORY_VIEW, FMDirectoryView))
+#define FM_DIRECTORY_VIEW_CLASS(klass) \
+  (G_TYPE_CHECK_CLASS_CAST ((klass), FM_TYPE_DIRECTORY_VIEW, FMDirectoryViewClass))
+#define FM_IS_DIRECTORY_VIEW(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FM_TYPE_DIRECTORY_VIEW))
+#define FM_IS_DIRECTORY_VIEW_CLASS(klass) \
+  (G_TYPE_CHECK_CLASS_TYPE ((klass), FM_TYPE_DIRECTORY_VIEW))
+#define FM_DIRECTORY_VIEW_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_CLASS ((obj), FM_TYPE_DIRECTORY_VIEW, FMDirectoryViewClass))
 
 typedef struct FMDirectoryViewDetails FMDirectoryViewDetails;
 
@@ -110,8 +114,16 @@ struct FMDirectoryViewClass {
 	 * of a directory are added to the view. It can be replaced by a 
 	 * subclass to do any necessary clean-up. The default implementation 
 	 * does nothing.
+	 *
+	 * If all_files_seen is true, the handler may assume that
+	 * no load error ocurred, and all files of the underlying
+	 * directory were loaded.
+	 *
+	 * Otherwise, end_loading was emitted due to cancellation,
+	 * which usually means that not all files are available.
 	 */
-	void 	(* end_loading) 	 (FMDirectoryView *view);
+	void 	(* end_loading) 	 (FMDirectoryView *view,
+					  gboolean all_files_seen);
 
 	/* The 'load_error' signal is emitted when the directory model
 	 * reports an error in the process of monitoring the directory's
@@ -121,8 +133,7 @@ struct FMDirectoryViewClass {
 	 * load failures like ACCESS_DENIED.
 	 */
 	void    (* load_error)           (FMDirectoryView *view,
-					  GnomeVFSResult result,
-					  const char *error_message);
+					  GError *error);
 
 	/* Function pointers that don't have corresponding signals */
 
@@ -158,6 +169,11 @@ struct FMDirectoryViewClass {
 
         void     (* set_selection)	 	(FMDirectoryView *view, 
         					 GList *selection);
+        					 
+        /* invert_selection is a function pointer that subclasses must
+         * override to invert selection. */
+
+        void     (* invert_selection)	 	(FMDirectoryView *view);        					 
 
 	/* Return an array of locations of selected icons in their view. */
 	GArray * (* get_selected_icon_locations) (FMDirectoryView *view);
@@ -205,6 +221,7 @@ struct FMDirectoryViewClass {
          * If overridden, subclasses must call parent class's function.
          */
         void    (* merge_menus)         	(FMDirectoryView *view);
+        void    (* unmerge_menus)         	(FMDirectoryView *view);
 
         /* update_menus is a function pointer that subclasses can override to
          * update the sensitivity or wording of menu items in the menu bar.
@@ -226,7 +243,7 @@ struct FMDirectoryViewClass {
 	 * be displayed with each file. By default, all emblems returned by
 	 * NautilusFile are displayed.
 	 */
-	EelStringList * (* get_emblem_names_to_exclude)	(FMDirectoryView *view);
+	char ** (* get_emblem_names_to_exclude)	(FMDirectoryView *view);
 
 	/* file_limit_reached is a function pointer that subclasses may
 	 * override to control what happens when a directory is loaded
@@ -298,6 +315,15 @@ struct FMDirectoryViewClass {
 						 NautilusFile	 *file,
 						 NautilusDirectory *directory);
 
+	/* convert *point from widget's coordinate system to a coordinate
+	 * system used for specifying file operation positions, which is view-specific.
+	 *
+	 * This is used by the the icon view, which converts the screen position to a zoom
+	 * level-independent coordinate system.
+	 */
+	void (* widget_to_file_operation_position) (FMDirectoryView *view,
+						    GdkPoint        *position);
+
 	/* Preference change callbacks, overriden by icon and list views. 
 	 * Icon and list views respond by synchronizing to the new preference
 	 * values and forcing an update if appropriate.
@@ -320,6 +346,7 @@ GType               fm_directory_view_get_type                         (void);
 
 /* Functions callable from the user interface and elsewhere. */
 NautilusWindowInfo *fm_directory_view_get_nautilus_window              (FMDirectoryView  *view);
+NautilusWindowSlotInfo *fm_directory_view_get_nautilus_window_slot     (FMDirectoryView  *view);
 char *              fm_directory_view_get_uri                          (FMDirectoryView  *view);
 char *              fm_directory_view_get_backing_uri                  (FMDirectoryView  *view);
 gboolean            fm_directory_view_can_accept_item                  (NautilusFile     *target_item,
@@ -328,6 +355,7 @@ gboolean            fm_directory_view_can_accept_item                  (Nautilus
 void                fm_directory_view_display_selection_info           (FMDirectoryView  *view);
 GList *             fm_directory_view_get_selection                    (FMDirectoryView  *view);
 GList *             fm_directory_view_get_selection_for_file_transfer  (FMDirectoryView  *view);
+void                fm_directory_view_invert_selection                 (FMDirectoryView  *view);
 void                fm_directory_view_stop                             (FMDirectoryView  *view);
 guint               fm_directory_view_get_item_count                   (FMDirectoryView  *view);
 gboolean            fm_directory_view_can_zoom_in                      (FMDirectoryView  *view);
@@ -359,6 +387,8 @@ void                fm_directory_view_move_copy_items                  (const GL
 									int               x,
 									int               y,
 									FMDirectoryView  *view);
+GdkAtom	            fm_directory_view_get_copied_files_atom            (FMDirectoryView  *view);
+gboolean            fm_directory_view_get_active                       (FMDirectoryView  *view);
 
 /* Wrappers for signal emitters. These are normally called 
  * only by FMDirectoryView itself. They have corresponding signals
@@ -366,26 +396,30 @@ void                fm_directory_view_move_copy_items                  (const GL
  */
 void                fm_directory_view_clear                            (FMDirectoryView  *view);
 void                fm_directory_view_begin_loading                    (FMDirectoryView  *view);
-void                fm_directory_view_end_loading                      (FMDirectoryView  *view);
+void                fm_directory_view_end_loading                      (FMDirectoryView  *view,
+									gboolean          all_files_seen);
 
 gboolean            fm_directory_view_get_loading                      (FMDirectoryView  *view);
 
 /* Hooks for subclasses to call. These are normally called only by 
  * FMDirectoryView and its subclasses 
  */
-void                fm_directory_view_activate_files                   (FMDirectoryView  *view,
-									GList            *files,
-									NautilusWindowOpenMode mode,
+void                fm_directory_view_activate_files                   (FMDirectoryView        *view,
+									GList                  *files,
+									NautilusWindowOpenMode  mode,
+									NautilusWindowOpenFlags flags,
+									gboolean                confirm_multiple);
+void                fm_directory_view_activate_file                    (FMDirectoryView        *view,
+									NautilusFile           *file,
+									NautilusWindowOpenMode  mode,
 									NautilusWindowOpenFlags flags);
 void                fm_directory_view_start_batching_selection_changes (FMDirectoryView  *view);
 void                fm_directory_view_stop_batching_selection_changes  (FMDirectoryView  *view);
-gboolean            fm_directory_view_confirm_multiple_windows         (FMDirectoryView  *view,
-									int               window_count);
 void                fm_directory_view_queue_file_change                (FMDirectoryView  *view,
 									NautilusFile     *file);
 void                fm_directory_view_notify_selection_changed         (FMDirectoryView  *view);
 GtkUIManager *      fm_directory_view_get_ui_manager                   (FMDirectoryView  *view);
-EelStringList *     fm_directory_view_get_emblem_names_to_exclude      (FMDirectoryView  *view);
+char **             fm_directory_view_get_emblem_names_to_exclude      (FMDirectoryView  *view);
 NautilusDirectory  *fm_directory_view_get_model                        (FMDirectoryView  *view);
 GtkWindow	   *fm_directory_view_get_containing_window	       (FMDirectoryView  *view);
 NautilusFile       *fm_directory_view_get_directory_as_file            (FMDirectoryView  *view);
@@ -396,7 +430,8 @@ void                fm_directory_view_pop_up_background_context_menu   (FMDirect
 void                fm_directory_view_pop_up_selection_context_menu    (FMDirectoryView  *view,
 									GdkEventButton   *event); 
 void                fm_directory_view_pop_up_location_context_menu     (FMDirectoryView  *view,
-									GdkEventButton   *event); 
+									GdkEventButton   *event,
+									const char       *location); 
 void                fm_directory_view_send_selection_change            (FMDirectoryView *view);
 gboolean            fm_directory_view_should_show_file                 (FMDirectoryView  *view,
 									NautilusFile     *file);
@@ -404,21 +439,29 @@ gboolean	    fm_directory_view_should_sort_directories_first    (FMDirectoryView
 void                fm_directory_view_update_menus                     (FMDirectoryView  *view);
 void                fm_directory_view_new_folder                       (FMDirectoryView  *view);
 void                fm_directory_view_new_file                         (FMDirectoryView  *view,
+									const char       *parent_uri,
 									NautilusFile     *source);
 void                fm_directory_view_ignore_hidden_file_preferences   (FMDirectoryView  *view);
+void                fm_directory_view_set_show_foreign                 (FMDirectoryView  *view,
+		                                                        gboolean          show_foreign);
 void                fm_directory_view_init_view_iface                  (NautilusViewIface *iface);
-void                fm_directory_view_handle_url_drop                  (FMDirectoryView  *view,
+gboolean            fm_directory_view_handle_scroll_event              (FMDirectoryView  *view,
+									GdkEventScroll   *event);
+void                fm_directory_view_handle_netscape_url_drop         (FMDirectoryView  *view,
 									const char       *encoded_url,
+									const char       *target_uri,
 									GdkDragAction     action,
 									int               x,
 									int               y);
 void                fm_directory_view_handle_uri_list_drop             (FMDirectoryView  *view,
 									const char       *item_uris,
+									const char       *target_uri,
 									GdkDragAction     action,
 									int               x,
 									int               y);
 void                fm_directory_view_handle_text_drop                 (FMDirectoryView  *view,
 									const char       *text,
+									const char       *target_uri,
 									GdkDragAction     action,
 									int               x,
 									int               y);
